/************************************************************************************
**    SIMphoto is an aplication based on single image photogrammetry. It is useful
**    for creating and printing a photomap. The software is designed for close
**    range photogrammtery. Outputs are usable in the field of heritage preservation.
**    Copyright (C) 2009 David Cizek
**
**    This program is free software: you can redistribute it and/or modify
**    it under the terms of the GNU General Public License as published by
**    the Free Software Foundation, either version 3 of the License, or
**    (at your option) any later version.
**
**    This program is distributed in the hope that it will be useful,
**    but WITHOUT ANY WARRANTY; without even the implied warranty of
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
**    GNU General Public License for more details.
**
**    You should have received a copy of the GNU General Public License
**    along with this program. If not, see <http://www.gnu.org/licenses/>.
**
**    How to contact me: cizekdav@gmail.com
**
***********************************************************************************/

#include "networkmethoddialog.h"

NetworkMethodDialog::NetworkMethodDialog(Matrix<double, 6, 1> DistValues, int diag, QWidget *parent)
    : QDialog(parent)
{
    insertDistLabel = new QLabel(this);
    bothDiagodalsRadioButton = new QRadioButton(tr("Both diagonals"), this);
    diagodal13RadioButton = new QRadioButton(tr("Diagonal 1 - 3"), this);
    diagodal24RadioButton = new QRadioButton(tr("Diagonal 2 - 4"), this);
    networkImage = new QImage("images/network.png");
    network13Image = new QImage("images/network13.png");
    network24Image = new QImage("images/network24.png");
    okButton = new QPushButton(tr("Ok"), this);

    QLabel *describtionLabel = new QLabel(this);
    QGridLayout *layout = new QGridLayout;
    QGridLayout *nestedLayout = new QGridLayout;

    for(int i = 0; i < 6; i++)
    {
        QDoubleSpinBox *distance = new QDoubleSpinBox(this);
        distance->setDecimals(3);
        distance->setValue(DistValues(i));

        listOfDistances.append(distance);
    }

    listOfDistances.at(0)->move(100, 19);
    listOfDistances.at(1)->move(193, 127);
    listOfDistances.at(2)->move(100, 223);
    listOfDistances.at(3)->move(3, 127);
    listOfDistances.at(4)->move(49, 69);
    listOfDistances.at(5)->move(49, 176);

    describtionLabel->setFont(QFont("Arial", 10, QFont::Bold));
    describtionLabel->setText(tr("Choose measured diagonal:"));

    nestedLayout->addWidget(bothDiagodalsRadioButton, 1, 0);
    nestedLayout->addWidget(diagodal13RadioButton, 2, 0);
    nestedLayout->addWidget(diagodal24RadioButton, 3, 0);
    nestedLayout->addWidget(okButton, 3, 1);

    insertDistLabel->setPixmap(QPixmap::fromImage(*networkImage));

    layout->addWidget(insertDistLabel, 0, 0);
    layout->addWidget(describtionLabel, 1, 0);
    layout->addLayout(nestedLayout, 2, 0);

    Qt::WindowFlags flags;
    flags = Qt::Dialog;
    flags |= Qt::WindowCloseButtonHint;

    setWindowFlags(flags);
    setLayout(layout);
    setMaximumSize(this->width(), this->height());
    setWindowTitle(tr("Type Measured Distances [m]"));
    setModal(true);

    if(diag == 0)
        bothDiagodalsRadioButton->setChecked(true);
    else if(diag == 1)
        diagodal13RadioButton->setChecked(true);
    else
        diagodal24RadioButton->setChecked(true);

    changeDiagonal();

    connect(bothDiagodalsRadioButton, SIGNAL(clicked()), this, SLOT(changeDiagonal()));
    connect(diagodal13RadioButton, SIGNAL(clicked()), this, SLOT(changeDiagonal()));
    connect(diagodal24RadioButton, SIGNAL(clicked()), this, SLOT(changeDiagonal()));
}

void NetworkMethodDialog::changeDiagonal()
{
    if(bothDiagodalsRadioButton->isChecked())
    {
        insertDistLabel->setPixmap(QPixmap::fromImage(*networkImage));
        listOfDistances.at(4)->show();
        listOfDistances.at(5)->show();
        diagonal = 0;
    }

    if(diagodal13RadioButton->isChecked())
    {
        insertDistLabel->setPixmap(QPixmap::fromImage(*network13Image));
        listOfDistances.at(5)->hide();
        listOfDistances.at(4)->show();
        diagonal = 1;
    }

    if(diagodal24RadioButton->isChecked())
    {
        insertDistLabel->setPixmap(QPixmap::fromImage(*network24Image));
        listOfDistances.at(5)->show();
        listOfDistances.at(4)->hide();
        diagonal = 2;
    }
}

QList<QDoubleSpinBox*> NetworkMethodDialog::getListOfDistances()
{
    return listOfDistances;
}

QPushButton* NetworkMethodDialog::getOkButton()
{
    return okButton;
}

int NetworkMethodDialog::getDiagonal()
{
    return diagonal;
}
